---
title: <span class="badge object-type-scalar"></span> Dollars
---
# <span class="badge object-type-scalar"></span> Dollars

Currency: Dollars ($)

## Definition

```python
# Currency: Dollars ($)
Dollars: typing.Literal["currencyUSD"] = "currencyUSD"
```
